@@ -6,7 +6,7 @@ use B::Hooks::EndOfScope 'on_scope_end';
 use Carp;
 
 # ABSTRACT: Sugar methods for declaring DBIx::Class::Result data definitions
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '2.00'; # VERSION
 
 
 our $CALLER; # can be used localized to wrap caller context into an anonymous sub
@@ -36,8 +36,8 @@ sub autoclean :Export(-) {
 }
 
 
-sub V1 :Export(-) {
-	shift->exporter_also_import('-swp',':V1','-autoclean');
+sub V2 :Export(-) {
+	shift->exporter_also_import('-swp',':V2','-autoclean');
 }
 sub exporter_autoload_symbol {
 	my ($self, $sym)= @_;
@@ -108,7 +108,14 @@ sub enable_inflate_json :Export(-inflate_json) {
 }
 
 
-my @V1= qw(
+sub enable_retrieve_defaults :Export(-retrieve_defaults) {
+	my $self= shift;
+	my $pkg= $self->{into};
+	_settings_for_package($pkg)->{retrieve_defaults}= 1;
+}
+
+
+my @V2= qw(
   table view
   col
     null default auto_inc fk
@@ -124,8 +131,8 @@ my @V1= qw(
 );
 
 our %EXPORT_TAGS;
-$EXPORT_TAGS{V1}= \@V1;
-export @V1;
+$EXPORT_TAGS{V2}= \@V2;
+export @V2;
 
 
 sub table {
@@ -153,6 +160,9 @@ sub col {
 		$dest->{$k}= $v;
 	}
 	my $pkg= $CALLER || caller;
+	$opts->{retrieve_on_insert}= 1
+		if $opts->{default_value} and !defined $opts->{retrieve_on_insert}
+			and _settings_for_package($pkg)->{retrieve_defaults};
 	$pkg->add_column($name, $opts);
 	1;
 }
@@ -248,8 +258,8 @@ sub bool        { data_type => 'boolean'.&_maybe_array, @_ }
 
 
 sub date        { data_type => 'date'.&_maybe_array, @_ }
-sub datetime    { my $tz= &_maybe_timezone; data_type => 'datetime'.&_maybe_array, ($tz? (time_zone => $tz) : ()), @_ }
-sub timestamp   { my $tz= &_maybe_timezone; data_type => 'timestamp'.&_maybe_array,($tz? (time_zone => $tz) : ()), @_ }
+sub datetime    { my $tz= &_maybe_timezone; data_type => 'datetime'.&_maybe_array, ($tz? (timezone => $tz) : ()), @_ }
+sub timestamp   { my $tz= &_maybe_timezone; data_type => 'timestamp'.&_maybe_array,($tz? (timezone => $tz) : ()), @_ }
 
 
 sub array {
@@ -439,6 +449,7 @@ sub dbic_cascade {
 		cascade_delete => $mode;
 }
 
+
 sub view {
         my ($name, $definition, %opts) = @_;
         my $pkg= $CALLER || caller;
@@ -455,7 +466,6 @@ sub view {
 }
 
 
-
 our %_installed_sqlt_hook_functions;
 sub _get_sqlt_hook_method_array {
 	my $pkg= shift;
@@ -531,12 +541,12 @@ DBIx::Class::ResultDDL - Sugar methods for declaring DBIx::Class::Result data de
 
 =head1 VERSION
 
-version 1.01
+version 2.00
 
 =head1 SYNOPSIS
 
   package MyApp::Schema::Result::Artist;
-  use DBIx::Class::ResultDDL qw/ -V1 -inflate_datetime -inflate_json /;
+  use DBIx::Class::ResultDDL qw/ -V2 -inflate_datetime -inflate_json /;
   
   table 'artist';
   col id           => integer unsigned auto_inc;
@@ -581,12 +591,16 @@ without this option overriding your choice.
 Then, C<< use parent "DBIx::Class::Core" >> unless the class already has an C<add_column>
 method.  If C<add_column> exists it is presumably because you already declared a parent class.
 Note that this check happens at BEGIN-time, so if you use Moo and C<< extends 'SomeClass'; >>
-you need to wrap that in a begin block before the C<< use DBIx::Class::ResultDDL -V1 >> line.
+you need to wrap that in a begin block before the C<< use DBIx::Class::ResultDDL -V2 >> line.
 
 =head2 C<-autoclean>
 
 Remove all added symbols at the end of current scope.
 
+=head2 C<-V2>
+
+Implies C<-swp>, C<:V2>, and C<-autoclean>.
+
 =head2 C<-V1>
 
 Implies C<-swp>, C<:V1>, and C<-autoclean>.
@@ -606,9 +620,21 @@ Causes all columns declared with C<json> or C<jsonb> sugar methods to also
 declare L</inflate_json>.  This requires L<DBIx::Class::InflateColumn::Serializer>
 to be installed (which is not an official dependency of this module).
 
+=head2 C<-retrieve_defaults>
+
+Causes all columns having a C<default_value> to also set C<< retrieve_on_insert => 1 >>.
+This way after an insert for a row having a date column with C<< default_value => \'NOW()' >>,
+the row object will hold the value of NOW() that was generated by the database.
+
+See L<DBIx::Class::ResultSource/retrieve_on_insert> for details on the column flag.
+
+This feature has no way of knowing about the existence of defaults in the database unless
+they were declared here in DBIx::Class metadata, nor does it know about triggers or other
+things that could cause the inserted row to be different from the insert request.
+
 =head1 EXPORTED COLLECTIONS
 
-=head2 C<:V1>
+=head2 C<:V2>
 
 This tag selects the following symbols:
 
@@ -625,6 +651,12 @@ This tag selects the following symbols:
   rel_one rel_many has_one might_have has_many belongs_to many_to_many
     ddl_cascade dbic_cascade
 
+=head2 C<:V1>
+
+See L<DBIx::Class::ResultDDL::V1>.  The primary difference from V2 is a bug in
+C<datetime($timezone)> where the timezone generated the wrong DBIC arguments.
+Also it didn't support C<-retrieve_defaults>.
+
 =head2 C<:V0>
 
 See L<DBIx::Class::ResultDDL::V0>.  The primary difference from V1 is lack of array
@@ -832,13 +864,17 @@ though in postgres 'bit' is used for bitstrings.
 =head3 datetime, timestamp
 
   datetime                      data_type => 'datetime'
-  datetime($tz)                 data_type => 'datetime', time_zone => $tz
+  datetime($tz)                 data_type => 'datetime', timezone => $tz
   datetime[]                    data_type => 'datetime[]'
-  datetime $tz, []              data_type => 'datetime[]', time_zone => $tz
+  datetime $tz, []              data_type => 'datetime[]', timezone => $tz
   
   # Same API
   timestamp ...                 data_type => 'timestamp', ...
 
+B<NOTE> that C<datetime> and C<timestamp> had a bug before version 2 which set "time_zone"
+instead of "timezone", causing the time zone (applied to DateTime objects by the inflator)
+to not take effect, resulting in "floating" timezone DateTime objects.
+
 =head3 array
 
   array($type)                  data_type => $type.'[]'
@@ -896,8 +932,10 @@ Note that the normal DBIC belongs_to requires conditions to be of the form
 
   { "foreign.$their_col" => "self.$my_col" }
 
-but all these sugar functions allow it to be written the other way around, and use a table
-name in place of "foreign.".
+but all these sugar functions allow it to be written the other way around, and use a
+Result Class name in place of "foreign.".  The Result Class may be a fully qualified
+package name, or just the final component if it is in the same parent package namespace
+as the current package.
 
 =head2 might_have
 
@@ -1065,7 +1103,7 @@ Veesh Goldman <rabbiveesh@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Michael Conrad, IntelliTree Solutions llc.
+This software is copyright (c) 2022 by Michael Conrad, IntelliTree Solutions llc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
